from django.core.management import BaseCommand
from django.utils.timezone import now

from cms.apps.pages.utils import publish_page
from ...models import publication_manager, Page


class Command(BaseCommand):
    '''
        Removes non-cannonical pages from the MPTT tree.
        Fixes Page MPTT left and right attributes.
    '''
    def handle(self, *args, **options):
        with publication_manager.select_published(False):
            pages = Page.objects.filter(version_for_id__isnull=False, version_publication_date__lte=now())
            for page in pages:
                publish_page(page)



import hmac

from django.conf import settings
from django.utils.crypto import salted_hmac
from django.utils.encoding import force_bytes


class PreviewTokenGenerator:
    key_salt = "PreviewTokenGenerator"
    secret = None

    def __init__(self, url):
        self.url = url
        self.secret = self.secret or settings.SECRET_KEY

    def verify(self, token):
        return hmac.compare_digest(force_bytes(self.make_token()), force_bytes(token))

    def make_token(self):
        hash_string = salted_hmac(
            self.key_salt,
            self._make_hash_value(),
            secret=self.secret,
        ).hexdigest()[::2]  # Limit to shorten the URL.
        return hash_string

    def _make_hash_value(self):
        return self.url



# Generated by Django 2.2.23 on 2021-05-19 15:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0018_page_version_publication_date'),
        ('pages', '0013_auto_20210326_1533'),
    ]

    operations = [
    ]



# Generated by Django 3.2 on 2021-05-20 09:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0019_merge_20210519_1633'),
    ]

    operations = [
        migrations.AlterField(
            model_name='country',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='countrygroup',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='page',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



# Generated by Django 2.2.9 on 2020-11-11 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0016_auto_20201102_2021'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='version_name',
            field=models.CharField(blank=True, help_text='Used to identify this version in the admin', max_length=100, null=True, verbose_name='draft name'),
        ),
    ]



# Generated by Django 2.2.9 on 2020-10-13 15:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0012_auto_20201009_1558'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='page',
            name='is_content_object',
        ),
        migrations.AddField(
            model_name='page',
            name='version',
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name='page',
            name='version_for',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='version_set', to='pages.Page'),
        ),
    ]
